*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* SISTEMA......: INFOFARMA
* PROGRAMA.....: USERED.PRG
* AUTOR........: EDUARDO V. FLORES RIVAS
* FECHA........: 04/03/95
* ACTUALIZADO..:
* COMENTARIOS..: LIBRERIA DE FUNCIONES PARA ENTORNO DE RED.
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
*
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_USE
* COMENTARIO: FUNCION PARA ABRIR UN ARCHIVO EN AMBIENTE RED.
*             Si no se necesita un alias colocar una coma sin argumentos.
*             Si SET EXCLUSIVE esta en OFF y se desea abrir el archivo
*             de forma compartida no es necesario pasar el parametro "S".
* SINTAXIS..: RED_USE (<archivo name>,<apodo>,<modo>,<intentos>)
*             Donde:
*             <archivo>   = Nombre del Archivo a abrir
*             <apodo>     = Alias del archivo a abrir
*             <modo>      = Modo de Apertura ("S"=Shared - "E"=Exclusive)
*             <tiempo>    = Nmero de intentos ante una falla segn neterr()
*                           si se omite el valor por defecto es 10
* EJEMPLO   : IF RED_USE (<archivo>,<apodo>,<modo>,<intentos>)
*                SET INDEX TO <indices>
*             ENDIF
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_USE(archivo,apodo,modo,tiempo)

LOCAL tmp:=0

modo:=IF(modo=NIL,'S',modo)
tiempo:=IF(tiempo=NIL,10,tiempo)
DO WHILE tmp<=tiempo
   IF modo='S'
      USE
      IF apodo=' ' .OR. apodo=NIL
         USE &archivo SHARED VIA "DBFCDX"
      ELSE
         USE &archivo ALIAS &apodo SHARED VIA "DBFCDX"
      ENDIF
   ELSE
      USE
      IF apodo=' ' .OR. apodo=NIL
         USE &archivo EXCLUSIVE VIA "DBFCDX"
      ELSE
         USE &archivo EXCLUSIVE ALIAS &apodo VIA "DBFCDX"
      ENDIF
   ENDIF

   IF .NOT. NETERR()
      RETURN(.T.)
   ELSE
      IF ! RED_MSGE({'Archivo '+archivo,' ya est en uso.','Imposible abrir.'})
         RETURN(.F.)
      ENDIF
   ENDIF
   tmp++
ENDDO

RETURN(.F.)


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_FLOCK
* COMENTARIO: FUNCION PARA ASEGURAR (LOCK) UN ARCHIVO
* SINTAXIS..: RED_FLOCK (tiempo)
*             Donde: <tiempo>=Nmero de intentos ante una falla segn flock()
*                    si se omite, el valor por defecto es 10.
* EJEMPLO...: IF RED_FLOCK (<tiempo>)
*                <actualizacin del archivo>
*             ENDIF
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_FLOCK(tiempo)

LOCAL tmp:=0

tiempo:=IF(tiempo=NIL,10,tiempo)
DO WHILE tmp<=tiempo
   IF FLOCK()
      RETURN(.T.)
   ELSE
      IF ! RED_MSGE({'Archivo ya est en uso.','Imposible grabar en archivo.'})
         RETURN(.F.)
      ENDIF
   ENDIF
   tmp++
ENDDO

RETURN(.F.)


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_RLOCK
* COMENTARIO: FUNCION PARA ASEGURAR (LOCK) UN REGISTRO
* SINTAXIS..: RED_RLOCK (tiempo)
*             Donde: <tiempo>=Nmero de intentos ante una falla segn rlock()
*                    si se omite, el valor por defecto es 10.
* EJEMPLO...: IF RED_RLOCK (<tiempo>)
*                <actualizacin del registro>
*             ENDIF
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_RLOCK(tiempo)

LOCAL tmp:=0

tiempo:=IF(tiempo=NIL,10,tiempo)
DO WHILE tmp<=tiempo
   IF RLOCK()
      RETURN(.T.)
   ELSE
      IF ! RED_MSGE({'Archivo est en uso.','Imposible grabar registro.'})
         RETURN(.F.)
      ENDIF
   ENDIF
   tmp++
ENDDO

RETURN(.F.)


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_APPE
* COMENTARIO: FUNCION PARA REALIZAR UN APPEND BLANK A UN ARCHIVO EN RED.
* SINTAXIS..: RED_APPE (tiempo)
*             Donde: <tiempo>=Nmero de intentos ante una falla
*                     segn neterr() si se omite, el valor por defecto es 10
* EJEMPLO...: IF RED_APPE (<tiempo>)
*                <actualizacin del registro>
*             ENDIF
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_APPE(tiempo)

LOCAL tmp:=0

tiempo:=IF(tiempo=NIL,10,tiempo)
DO WHILE tmp<=tiempo
   APPE BLANK
   IF .NOT. NETERR()
      RETURN(.T.)
   ELSE
      IF ! RED_MSGE({'Archivo est en uso.','Imposible agregar registro.'})
         RETURN(.F.)
      ENDIF
   ENDIF
   tmp++
ENDDO

RETURN(.F.)


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_MSGE
* COMENTARIO: FUNCION PARA LOS MENSAJES DE LAS FUNCIONES DE RED
* SINTAXIS..: RED_MSGE(<mensaje>)
*             Donde: <mensaje>=mensaje a presentar en la barra de mensajes
* EJEMPLO...: IF RED_MSGE(<mensaje>)
*                <proceso>
*             ENDIF
*
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_MSGE(mensaje)

IF MsgYesNo('ERROR de Interbloqueo :  Desea reintentar ?')
   RETURN(.T.)
ELSE
   RETURN(.F.)
ENDIF


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_COMMIT
* COMENTARIO: FUNCION PARA GRABAR Y LIBERAR UN REGISTRO
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_COMMIT

DBCOMMIT()

RETURN


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_UNLOCK
* COMENTARIO: FUNCION PARA LIBERAR UN ARCHIVO
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_UNLOCK

COMMIT
UNLOCK

RETURN


*-------------------------------------------------------------------------
*-------------------------------------------------------------------------
* FUNCION...: RED_FUNLOCK
* COMENTARIO: FUNCION PARA LIBERAR UN ARCHIVO
*-------------------------------------------------------------------------
*-------------------------------------------------------------------------

FUNC RED_FUNLOCK

COMMIT
UNLOCK

RETURN